==> flutter_kz_library-0.0.8.tar.gz: example/lib/src/screens/routes.dart <==
import 'package:example/src/screens/account/AccountPage.dart';
import 'package:flutter/material.dart';
import 'package:flutter_kz_library/flutter_kz_library.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'home/HomePage.dart';

class Routes extends StatefulWidget {
  @override
  _RoutesState createState() => _RoutesState();
}

class _RoutesState extends State<Routes> {
  final PageStorageBucket bucket = PageStorageBucket();
  final List<Widget> pages = [
    HomePage(
      key: PageStorageKey('HomePage'),
    ),
    AccountPage(
      key: PageStorageKey('AccountPage'),
    )
  ];

  int _currentIndex = 0;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      bottomNavigationBar: BubbleBottomBarWidget(
        currentIndex: _currentIndex,
        onSelectIndex: (index) => setState(() {
          _currentIndex = index;
        }),
        items: [
          Statics.bubbleBottomBarItem(
              backgroundColor: Colors.red,
              icon: Icon(
                Icons.home,
                color: Colors.black,
                size: 18,
              ),
              activeIcon: Icon(
                Icons.home,
                color: Colors.red,
                size: 18,
              ),
              title: Text(
                "Project",
                style: TextStyle(fontSize: 12),
              )),
          Statics.bubbleBottomBarItem(
              backgroundColor: Colors.teal,
              icon: Icon(
                Icons.account_circle,
                color: Colors.black,
                size: 18,
              ),
              activeIcon: Icon(
                Icons.account_circle,
                color: Colors.teal,
                size: 18,
              ),
              title: Text(
                "Project",
                style: TextStyle(fontSize: 12),
              ))
        ],
      ),
      body: PageStorage(
        child: pages[_currentIndex],
        bucket: bucket,
      ),
      floatingActionButton: speedDialWidget(
        context: context,
        children: [
          Statics.speedDialChild(
              child: Icon(FontAwesomeIcons.qrcode),
              backgroundColor: Colors.red,
              label: 'Scan',
              labelStyle: TextStyle(fontSize: 18.0),
              onTap: () => ToastHelper().showToastSuccess(context: context, message: 'qrcode', gravity: toastGravity.center)
          )
        ]
      ),
    );
  }
}

==> flutter_kz_library-0.1.1.tar.gz: example/lib/src/screens/routes.dart <==
import 'package:example/src/screens/account/AccountPage.dart';
import 'package:flutter/material.dart';
import 'package:flutter_kz_library/flutter_kz_library.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'home/HomePage.dart';
import 'notification/NotificationPage.dart';

class Routes extends StatefulWidget {
  @override
  _RoutesState createState() => _RoutesState();
}

class _RoutesState extends State<Routes> {
  final PageStorageBucket bucket = PageStorageBucket();
  final List<Widget> pages = [
    HomePage(
      key: PageStorageKey('HomePage'),
    ),
    NotificationPage(
      key: PageStorageKey('NotificationPage'),
    ),
    AccountPage(
      key: PageStorageKey('AccountPage'),
    )
  ];

  int _currentIndex = 0;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      bottomNavigationBar: BubbleBottomBarWidget(
        currentIndex: _currentIndex,
        onSelectIndex: (index) => setState(() {
          _currentIndex = index;
        }),
        items: [
          Statics.bubbleBottomBarItem(
              backgroundColor: Colors.red,
              icon: Icon(
                Icons.home,
                color: Colors.black,
                size: 18,
              ),
              activeIcon: Icon(
                Icons.home,
                color: Colors.red,
                size: 18,
              ),
              title: Text(
                "Project",
                style: TextStyle(fontSize: 12),
              )),
          Statics.bubbleBottomBarItem(
              backgroundColor: Colors.purple,
              icon: Icon(
                Icons.notifications,
                color: Colors.black,
                size: 18,
              ),
              activeIcon: Icon(
                Icons.notifications,
                color: Colors.purple,
                size: 18,
              ),
              title: Text(
                "Notification",
                style: TextStyle(fontSize: 12),
              )),
          Statics.bubbleBottomBarItem(
              backgroundColor: Colors.teal,
              icon: Icon(
                Icons.account_circle,
                color: Colors.black,
                size: 18,
              ),
              activeIcon: Icon(
                Icons.account_circle,
                color: Colors.teal,
                size: 18,
              ),
              title: Text(
                "Account",
                style: TextStyle(fontSize: 12),
              ))
        ],
      ),
      body: PageStorage(
        child: pages[_currentIndex],
        bucket: bucket,
      ),
      floatingActionButton: speedDialWidget(
        context: context,
        children: [
          Statics.speedDialChild(
              child: Icon(FontAwesomeIcons.qrcode),
              backgroundColor: Colors.red,
              label: 'Scan',
              labelStyle: TextStyle(fontSize: 18.0),
              onTap: () => Helper.toastHelper.showToastSuccess(context: context, message: 'qrcode', gravity: toastGravity.center)
          )
        ]
      ),
    );
  }
}
